@@ -1,32 +1,13 @@
-from .trainer import Trainer, nn, optim, Optional, List, HookBase, torch
+from .trainer import Trainer, nn, optim, Optional, List, HookBase, setup_logger, logger
+import os
 from torch.utils.data import DataLoader, Dataset, DistributedSampler, RandomSampler
-import torch.distributed as dist
-
-
-def is_dist_avail_and_initialized():
-    if not dist.is_available():
-        return False
-    if not dist.is_initialized():
-        return False
-    return True
-
-
-def get_world_size():
-    if not is_dist_avail_and_initialized():
-        return 1
-    return dist.get_world_size()
-
-
-def get_rank():
-    if not is_dist_avail_and_initialized():
-        return 0
-    return dist.get_rank()
+from .utils.dist_utils import *
 
 
 class DDPTrainer(Trainer):
     """
     Trainer的DDP版本。需要注意的是，在调用该类前依然要执行init_process_group，为了避免重复打印或保存数据，应该在外部选择性
-    的根据gpu_id调用hooker
+    的根据gpu_id调用hooker, 在创建DDPTrainer对象时会自动根据环境判断是否使用ddp，无需手动设置
     """
 
     def __init__(self,
@@ -43,7 +24,6 @@ class DDPTrainer(Trainer):
                  warmup_iters: int = 1000,
                  warmup_factor: float = 0.001,
                  hooks: Optional[List[HookBase]] = None,
-                 use_dist: bool = False,
                  create_new_dir: Optional[str] = "time_s"
                  ):
         """
@@ -76,7 +56,6 @@ class DDPTrainer(Trainer):
             warmup初始学习率 = warmup_factor * initial_lr
         hooks : List[HookBase], default None.
             hooks, 保存模型、输出评估指标、loss等用
-        use_dist : bool, default False. 是否使用ddp
         create_new_dir : Optional[str], default time
             存在同名目录时以何种策略创建目录
             * None, 直接使用同名目录
@@ -86,8 +65,8 @@ class DDPTrainer(Trainer):
             * `time_d`, 如果已经存在同名目录, 则以时间(精确到日)为后缀创建新目录
             * `count`, 如果已经存在同名目录, 则以序号为后缀创建新目录
         """
-
-        if use_dist:
+        self.use_dist = is_dist_avail_and_initialized()
+        if self.use_dist:
             num_tasks = get_world_size()
             global_rank = get_rank()
             sampler_trainer = DistributedSampler(dataset, num_replicas=num_tasks, rank=global_rank)
@@ -97,7 +76,6 @@ class DDPTrainer(Trainer):
         super(DDPTrainer, self).__init__(model, optimizer, lr_scheduler, data_loader, max_epochs, work_dir,
                                          clip_grad_norm, enable_amp,  warmup_method, warmup_iters, warmup_factor,
                                          hooks, create_new_dir)
-        self.use_dist = use_dist
 
     def _train_one_epoch(self) -> None:
         """执行模型一个epoch的全部操作"""
@@ -106,5 +84,39 @@ class DDPTrainer(Trainer):
             self.data_loader.sampler.set_epoch(self.epoch)
         super(DDPTrainer, self)._train_one_epoch()
 
+    def _prepare_for_training(self,
+                              console_log_level: int = 2,
+                              file_log_level: int = 2) -> None:
+        """
+        训练前的配置工作
+        Parameters
+        ----------
+        console_log_level : int, default 2
+             输出到屏幕的log等级, 可选范围是0-5, 它们对应的关系分别为：
+             * 5: FATAL
+             * 4: ERROR
+             * 3: WARNING
+             * 2: INFO
+             * 1: DEBUG
+             * 0: NOTSET
+        file_log_level : int, default 2
+             输出到文件里的log等级, 其他方面同console_log_level参数
+        """
+        assert console_log_level in (0, 1, 2, 3, 4, 5), f"console_log_level必须在0~5之间而不是{console_log_level}"
+        assert file_log_level in (0, 1, 2, 3, 4, 5), f"file_log_level必须在0~5之间而不是{file_log_level}"
+        console_log_level *= 10
+        file_log_level *= 10
+        setup_logger("torch_frame", output=self.log_file,
+                     console_log_level=console_log_level, file_log_level=file_log_level)
+
+        if self.start_epoch == 0 and get_rank() == 0:
+            os.makedirs(self.ckpt_dir, exist_ok=True)
+            logger.info(f"Registered default hooks: {self.registered_hook_names}")
+            split_line = "-" * 50
+            logger.info(
+                f"\n{split_line}\n"
+                f"Work directory: {self.work_dir}\n"
+                f"{split_line}"
+            )
 
         
\ No newline at end of file
